==> larus_board-0.9.9.zip: larus_board-0.9.9/lb_private/lang/en/help.php <==
<?php
/* LARUS BOARD ========================================================
 * Encoded in UTF-8 (micro symbol: µ)
 * Copyright © 2008 by "The Larus Board Team"
 * This file is part of "Larus Board" and is licensed under
 * Creative Commons Attribution-Share Alike 3.0
 *
 * You should have received a copy of the license
 * along with this package. If not, see
 * <http://download.savannah.gnu.org/releases/larusboard/COPYING.CC>.
 */
$lang = array(
'help_ask_support'=>'If you have a difficult question concerning this forum or any technical issues on your user account, please contact our support under the following conditions.',
'help_format_bgcolor'=>'Background Color',
'help_format_bold'=>'Bold',
'help_format_color'=>'Text Color',
'help_format_inline'=>'Inline (no line break)',
'help_format_italic'=>'Italic',
'help_format_size'=>'Text Size',
'help_format_underline'=>'Underline',
'help_overview'=>'Before you ask us for help directly, please have a look at the following comprehensive knowledge base. Many questions are already answered here and if you have a simple question about using our forum, you may ask it straightaway by posting a new topic. If you think you need "advanced" help or your problem is not solved here, then please feel free to contact us for support (see right side).',
'help_popup_insert_anchor'=>'You can include an anchor in your message and link to it elsewhere',
'help_popup_insert_format'=>'You can apply special formatting. First select some text and then insert formatting',
'help_popup_insert_link'=>'You can link to another posting in our forum or an anchor in your posting',
'help_popup_insert_mail'=>'Please provide an e-mail address you would like to include',
'help_popup_insert_uri'=>'Please provide a full URI of the object you would like to link to',
'help_popup_mcp_rss'=>'Please give your password and fetch the resulting URL to subscribe to the feed.',
'help_popup_search_user'=>'Search for username (use * as wildcard)',
'help_popup_title'=>'Little Helpful Toolbox',
'help_support_by_forum'=>'Please post a new topic in our forum. Use a descriptive subject line, add the prefix "Support Request" and include all neccessary information. A simple "help me!!11!" will not be accepted. We try to help you as fast as possible, but please be a little patient. Thank you :)',
'help_support_by_mail'=>'Please send an e-mail to the shown address. Use a descriptive subject line and include all neccessary information. A simple "help me!!11!" will not be accepted. We try to help you as fast as possible, but please be a little patient. Thank you :)',
'insert'=>'Insert'
);
?>

==> larus_board-0.9.18.zip: larus_board-0.9.18/lb_private/lang/en/help.php <==
<?php
/* LARUS BOARD ========================================================
 * Encoded in UTF-8 (micro symbol: µ)
 * Copyright © 2008,2009 by "The Larus Board Team"
 * This file is part of "Larus Board" and is licensed under
 * Creative Commons Attribution-Share Alike 3.0
 *
 * You should have received a copy of the license
 * along with this package. If not, see
 * <http://download.savannah.gnu.org/releases/larusboard/COPYING.CC>.
 */
$lang = array(
'help_ask_support'=>'If you have a difficult question concerning this forum or any technical issues on your user account, please contact our support under the following conditions.',
'help_format_bgcolor'=>'Background Color',
'help_format_bold'=>'Bold',
'help_format_color'=>'Text Color',
'help_format_inline'=>'Inline (no line break)',
'help_format_italic'=>'Italic',
'help_format_left'=>'Make block float left',
'help_format_right'=>'Make block float right',
'help_format_size'=>'Text Size',
'help_format_underline'=>'Underline',
'help_format_width'=>'Width',
'help_overview'=>'Before you ask us for help directly, please have a look at the following comprehensive knowledge base. Many questions are already answered here and if you have a simple question about using our forum, you may ask it straightaway by posting a new topic. If you think you need "advanced" help or your problem is not solved here, then please feel free to contact us for support (see right side).',
'help_popup_insert_anchor'=>'You can include an anchor in your message and link to it elsewhere',
'help_popup_insert_format'=>'You can apply special formatting. First select some text and then insert formatting',
'help_popup_insert_link'=>'You can link to another posting in our forum or an anchor in your posting',
'help_popup_insert_mail'=>'Please provide an e-mail address you would like to include',
'help_popup_insert_uri'=>'Please provide a full URI of the object you would like to link to',
'help_popup_mcp_rss'=>'Please give your password and fetch the resulting URL to subscribe to the feed.',
'help_popup_search_user'=>'Search for username (use * as wildcard)',
'help_popup_title'=>'Little Helpful Toolbox',
'help_support_by_forum'=>'Please post a new topic in our forum. Use a descriptive subject line, add the prefix "Support Request" and include all neccessary information. A simple "help me!!11!" will not be accepted. We try to help you as fast as possible, but please be a little patient. Thank you :)',
'help_support_by_mail'=>'Please send an e-mail to the shown address. Use a descriptive subject line and include all neccessary information. A simple "help me!!11!" will not be accepted. We try to help you as fast as possible, but please be a little patient. Thank you :)',
'insert'=>'Insert'
);
?>
